@@ -90,7 +90,7 @@ jQuery.tabbedportlet = function(options) {
 			filters.push(ops.portletDataNodeType+'.'+ops.portletDataNodeClasses[i]);
 		var elements = jQuery(filters.join(','), jqe).remove();
 		
-		var header_text = jQuery.trim(jQuery(ops.portletHeaderNodeType+'.'+ops.portletHeaderNodeClasses.join('.'), jqe).remove().children().text());
+		var header_text = jQuery.trim(jQuery(ops.portletHeaderNodeType+'.'+ops.portletHeaderNodeClasses.join('.'), jqe).remove().text());
 		if (tabOps.cutChars && header_text.length>tabOps.cutChars-1)
 			header_text=header_text.substr(0,tabOps.cutChars)+"&hellip;";
 		else if (tabOps.label)
